[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# AST
Implementation of AST from the paper: "AST: Audio Spectrogram Transformer' in PyTorch and Zeta.

## Install
`pip3 install ast-torch`

## Usage
```

```


# License
MIT



